@@ -16,6 +16,7 @@ __all__ = [
     "validate_yaml",
     "lint_all",
     "validators",
+    "get_sso_token",
     "write_jsroot_compression_options",
 ]
 
@@ -23,6 +24,7 @@ from os.path import join
 
 from . import hacks, validators
 from .linting import lint_all
+from .new_cern_sso import get_sso_token
 from .parsing import parse_yaml, render_yaml, validate_yaml
 
 
